@echo off
del  *.toc /s
del  *.bbl /s
del  *.blg /s
del  *.out  /s
del  *.aux  /s
del  *.log  /s
del  *.bak  /s
del  *.thm  /s
del  *.synctex.gz /s
del  *.fdb_latexmk /s
del  *.fls /s
del  *.glo /s
del  *.gls /s
del  *.idx /s
del  *.ilg /s
del  *.ind /s
del  *.nav /s
del  *.snm /s
del  *.hd /s
del  *.ins /s
del  *.sty /s